@@ -75,7 +75,7 @@ class ModelingBertTest(tf.test.TestCase):
             return_states=return_states,
             return_attention_weights=return_attention_weights)
         input_ids, segment_ids, attn_mask = self._build_bert_inputs()
-        outputs = model(input_ids, segment_ids, attn_mask)
+        outputs = model(inputs=(input_ids, segment_ids, attn_mask))
         sequence_outputs, pooled_outputs = outputs[0], outputs[1]
         self.assertAllEqual([2, 16, 768], sequence_outputs.shape)
         self.assertAllEqual([2, 768], pooled_outputs.shape)
@@ -137,7 +137,7 @@ class ModelingBertTest(tf.test.TestCase):
     def test_build_model(self):
         model = Bert(vocab_size=21128)
         input_ids, segment_ids, input_mask = model.dummy_inputs()
-        model(input_ids, segment_ids, input_mask)
+        model(inputs=(input_ids, segment_ids, input_mask))
         model.summary()
 
 
