@@ -10,7 +10,7 @@ from transformers_keras.adapters.albert_adapter import AlbertAdapter
 from .layers import MultiHeadAttention
 from .modeling_bert import BertEmbedding, BertEncoderLayer, BertIntermediate
 from .modeling_utils import (choose_activation, complete_inputs, initialize,
-                             unpack_inputs_2)
+                             unpack_inputs_2, unpack_inputs_3)
 
 
 class AlbertEmbedding(tf.keras.layers.Layer):
@@ -344,8 +344,8 @@ class Albert(tf.keras.Model):
         self.return_states = return_states
         self.return_attention_weights = return_attention_weights
 
-    def call(self, input_ids, segment_ids, attention_mask, training=None):
-        input_ids, segment_ids, attention_mask = complete_inputs(input_ids, segment_ids, attention_mask)
+    def call(self, inputs, training=None):
+        input_ids, segment_ids, attention_mask = unpack_inputs_3(inputs)
 
         attention_mask = attention_mask[:, tf.newaxis, tf.newaxis, :]
         embed = self.embedding(inputs=(input_ids, segment_ids), mode='embedding')
@@ -375,7 +375,7 @@ class Albert(tf.keras.Model):
         model_config['return_attention_weights'] = kwargs.get('return_attention_weights', False)
         model = cls(**model_config)
         input_ids, segment_ids, attn_mask = model.dummy_inputs()
-        model(input_ids, segment_ids, attn_mask)
+        model(inputs=(input_ids, segment_ids, attn_mask))
         adapter.adapte_weights(model, model_config, ckpt, **kwargs)
         return model
 
